netapp_ontap.models.flexcache_relationship API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.flexcache_relationship`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FlexcacheRelationshipSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FlexcacheRelationship object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cluster GET POST PATCH`

    The cluster field of the flexcache_relationship.

  `create_time GET`

    Creation time of the relationship.

    Example: 2018-06-04T19:00:00.000+0000

  `ip_address GET`

    Cluster managerment IP of the remote cluster.

    Example: 10.10.10.7

  `size GET`

    Size of the remote volume.

  `state GET`

    Volume state

    Valid choices:

    - error
    - mixed
    - offline
    - online
  `svm GET POST`

    The svm field of the flexcache_relationship.

  `volume GET POST PATCH`

    The volume field of the flexcache_relationship.